darkhistory.spec.pppc.get_pppc_spec — DarkHistory documentation

# darkhistory.spec.pppc.get_pppc_spec

`darkhistory.spec.pppc.` `get_pppc_spec`(mDM, eng, pri, sec, decay=False)

  Returns the PPPC4DMID spectrum.

  This is the secondary spectrum to e+e-/photons normalized to one annihilation or decay event to the species specified in `pri`. These results include electroweak corrections. The full list of allowed channels is:

  - \(\delta\)-function injections: `elec_delta, phot_delta`
  - Leptons: `e_L, e_R, e, mu_L, mu_R, mu, tau_L, tau_R, tau`
  - Quarks: `q, c, b, t`
  - Gauge bosons: `gamma, g, W_L, W_T, W, Z_L, Z_T, Z`
  - Higgs: `h`

  `elec_delta` and `phot_delta` assumes annihilation or decay to two electrons and photons respectively with no EW corrections or ISR/FSR.

  Variables with subscripts, e.g. `e_L`, correspond to particles with different polarizations. These polarizations are suitably averaged to obtain the spectra returned in their corresponding variables without subscripts, e.g. `e`.

  Parameters: | mDM : float The mass of the annihilating dark matter particle (in eV). eng : ndarray The energy abscissa for the output spectrum (in eV). pri : string One of the available channels (see Notes). sec : {‘elec’, ‘phot’} The secondary spectrum to obtain. decay : bool, optional If `True`, returns the result for decays.
  Returns: | Spectrum Output `Spectrum` object, `spec_type == 'dNdE'`.

#### Previous topic

darkhistory.spec.pppc

#### Next topic

darkhistory.spec.spectools

### This Page

Show Source